@@ -374,8 +374,8 @@ static int oauth_strcmp(zval *first, zval *second)
 static int oauth_compare_value(const void *a, const void *b)
 {
 	Bucket *f, *s;
-	f = *(Bucket **)a;
-	s = *(Bucket **)b;
+	f = (Bucket *)a;
+	s = (Bucket *)b;
 
 	return oauth_strcmp(&f->val, &s->val);
 }
@@ -577,14 +577,14 @@ zend_string *oauth_generate_sig_base(php_so_object *soo, const char *http_method
 			php_url_free(urlparts);
 			return NULL;
 		}
-		php_strtolower(urlparts->scheme, strlen(urlparts->scheme));
-		php_strtolower(urlparts->host, strlen(urlparts->host));
-		smart_string_appends(&sbuf, urlparts->scheme);
+		php_strtolower(OAUTH_URL_STR(urlparts->scheme), OAUTH_URL_LEN(urlparts->scheme));
+		php_strtolower(OAUTH_URL_STR(urlparts->host), OAUTH_URL_LEN(urlparts->host));
+		smart_string_appends(&sbuf, OAUTH_URL_STR(urlparts->scheme));
 		smart_string_appends(&sbuf, "://");
-		smart_string_appends(&sbuf, urlparts->host);
+		smart_string_appends(&sbuf, OAUTH_URL_STR(urlparts->host));
 
-		if (urlparts->port && ((!strcmp("http", urlparts->scheme) && OAUTH_HTTP_PORT != urlparts->port)
-					|| (!strcmp("https", urlparts->scheme) && OAUTH_HTTPS_PORT != urlparts->port))) {
+		if (urlparts->port && ((!strcmp("http", OAUTH_URL_STR(urlparts->scheme)) && OAUTH_HTTP_PORT != urlparts->port)
+					|| (!strcmp("https", OAUTH_URL_STR(urlparts->scheme)) && OAUTH_HTTPS_PORT != urlparts->port))) {
 			spprintf(&s_port, 0, "%d", urlparts->port);
 			smart_string_appendc(&sbuf, ':');
 			smart_string_appends(&sbuf, s_port);
@@ -593,7 +593,7 @@ zend_string *oauth_generate_sig_base(php_so_object *soo, const char *http_method
 
 		if (urlparts->path) {
 			smart_string squery = {0};
-			smart_string_appends(&sbuf, urlparts->path);
+			smart_string_appends(&sbuf, OAUTH_URL_STR(urlparts->path));
 			smart_string_0(&sbuf);
 
 			array_init(&params);
@@ -608,7 +608,7 @@ zend_string *oauth_generate_sig_base(php_so_object *soo, const char *http_method
 			}
 
 			if (urlparts->query) {
-				query = estrdup(urlparts->query);
+				query = estrdup(OAUTH_URL_STR(urlparts->query));
 				oauth_parse_str(query, &params);
 				efree(query);
 			}
@@ -794,18 +794,19 @@ static long make_req_streams(php_so_object *soo, const char *url, const smart_st
 	}
 
 	if (request_headers) {
+		HashPosition pos;
 		zval *cur_val, zheaders;
 		zend_string *cur_key;
 		ulong num_key;
 		smart_string sheaders = {0};
 		int first = 1;
 
-		for (zend_hash_internal_pointer_reset(request_headers);
-				(cur_val = zend_hash_get_current_data(request_headers)) != NULL;
-				zend_hash_move_forward(request_headers)) {
+		for (zend_hash_internal_pointer_reset_ex(request_headers, &pos);
+				(cur_val = zend_hash_get_current_data_ex(request_headers, &pos)) != NULL;
+				zend_hash_move_forward_ex(request_headers, &pos)) {
 			/* check if a string based key is used */
 			smart_string sheaderline = {0};
-			switch (zend_hash_get_current_key(request_headers, &cur_key, &num_key)) {
+			switch (zend_hash_get_current_key_ex(request_headers, &cur_key, &num_key, &pos)) {
 				case HASH_KEY_IS_STRING:
 					smart_string_appendl(&sheaderline, ZSTR_VAL(cur_key), ZSTR_LEN(cur_key));
 					break;
@@ -876,16 +877,17 @@ static long make_req_streams(php_so_object *soo, const char *url, const smart_st
 
 		if (Z_TYPE(s->wrapperdata) != IS_UNDEF) {
 			zval *tmp;
+			HashPosition pos;
 
-			zend_hash_internal_pointer_reset(Z_ARRVAL(s->wrapperdata));
-			while ((tmp = zend_hash_get_current_data(Z_ARRVAL(s->wrapperdata))) != NULL) {
+			zend_hash_internal_pointer_reset_ex(Z_ARRVAL(s->wrapperdata), &pos);
+			while ((tmp = zend_hash_get_current_data_ex(Z_ARRVAL(s->wrapperdata), &pos)) != NULL) {
 				smart_string_appendl(&soo->headers_in, Z_STRVAL_P(tmp), Z_STRLEN_P(tmp));
 				smart_string_appends(&soo->headers_in, "\r\n");
 				HTTP_RESPONSE_CODE(tmp);
 				HTTP_RESPONSE_LOCATION(tmp);
 				HTTP_RESPONSE_CAAS(tmp, "Content-Type: ", "content_type");
 				HTTP_RESPONSE_CAAD(tmp, "Content-Length: ", "download_content_length");
-				zend_hash_move_forward(Z_ARRVAL(s->wrapperdata));
+				zend_hash_move_forward_ex(Z_ARRVAL(s->wrapperdata), &pos);
 			}
 			if (HTTP_IS_REDIRECT(response_code) && soo->last_location_header) {
 				CAAS("redirect_url", soo->last_location_header);
@@ -1364,11 +1366,11 @@ static void oauth_apply_url_redirect(smart_string *surl, const char *location) /
 		/* rebuild url from scratch */
 		smart_string_free(surl);
 		if (urlparts->scheme) {
-			smart_string_appends(surl, urlparts->scheme);
+			smart_string_appends(surl, OAUTH_URL_STR(urlparts->scheme));
 			smart_string_appends(surl, "://");
 		}
 		if (urlparts->host) {
-			smart_string_appends(surl, urlparts->host);
+			smart_string_appends(surl, OAUTH_URL_STR(urlparts->host));
 		}
 		if (urlparts->port) {
 			smart_string_appendc(surl, ':');
