@@ -132,7 +132,7 @@ static int oauth_provider_token_required(zval *provider_obj, char* uri)
 			if (reqtoken_path[0]=='/') {
 				/* match against relative url */
 				php_url *urlparts = php_url_parse_ex(uri, strlen(uri));
-				uri_matched = urlparts && 0==strncmp(urlparts->path, reqtoken_path, strlen(reqtoken_path));
+				uri_matched = urlparts && 0==strncmp(OAUTH_URL_STR(urlparts->path), reqtoken_path, strlen(reqtoken_path));
 				php_url_free(urlparts);
 			} else {
 				/* match against full uri */
@@ -864,11 +864,11 @@ SOP_METHOD(setParam)
 	sop = fetch_sop_object(pthis);
 
 	if (!param_val) {
-		RETURN_BOOL(SUCCESS == zend_hash_str_del(sop->custom_params, param_key, param_key_len) ? IS_TRUE : IS_FALSE);
+		RETURN_BOOL(SUCCESS == zend_hash_str_del(sop->custom_params, param_key, param_key_len));
 	} else {
 		Z_TRY_ADDREF_P(param_val);
 
-		RETURN_BOOL(NULL != zend_hash_str_add(sop->custom_params, param_key, param_key_len, param_val) ? IS_TRUE : IS_FALSE);
+		RETURN_BOOL(NULL != zend_hash_str_add(sop->custom_params, param_key, param_key_len, param_val));
 	}
 }
 /* }}} */
@@ -1048,7 +1048,7 @@ SOP_METHOD(reportProblem)
 		default:
 			http_code = OAUTH_ERR_INTERNAL_ERROR;
 			out = emalloc(48);
-			snprintf(out, 48, "oauth_problem=unknown_problem&code=%d", lcode);
+			snprintf(out, 48, "oauth_problem=unknown_problem&code=%lu", lcode);
 			out_malloced = 1;
 	}
 
